@@ -17,11 +17,26 @@ except ImportError:
         pass
 from struct import unpack
 
-from amqplib import client_0_8 as amqp
-from amqplib.client_0_8 import transport
-from amqplib.client_0_8.channel import Channel as _Channel
-from amqplib.client_0_8.exceptions import AMQPConnectionException
-from amqplib.client_0_8.exceptions import AMQPChannelException
+try:
+    from amqplib import client_0_8 as amqp
+    from amqplib.client_0_8 import transport
+    from amqplib.client_0_8.channel import Channel as _Channel
+    from amqplib.client_0_8.exceptions import AMQPConnectionException
+    from amqplib.client_0_8.exceptions import AMQPChannelException
+except ImportError:  # pragma: no cover
+
+    class NA(object):
+        pass
+
+    class NAx(object):
+        pass
+    amqp = NA
+    amqp.Connection = NA
+    transport = _Channel = NA                               # noqa
+    # Sphinx crashes if this is NA, must be different class
+    transport.TCPTransport = transport.SSLTransport = NAx
+    AMQPConnectionException = AMQPChannelException = NA     # noqa
+
 
 from kombu.five import items
 from kombu.utils.encoding import str_to_bytes
@@ -321,6 +336,9 @@ class Transport(base.Transport):
         self.client = client
         self.default_port = kwargs.get('default_port') or self.default_port
 
+        if amqp is NA:
+            raise ImportError('Missing amqplib library (pip install amqplib)')
+
     def create_channel(self, connection):
         return connection.channel()
 
